summaryrefslogtreecommitdiff
path: root/tests/test_runner
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test_runner')
-rw-r--r--tests/test_runner/tests.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/test_runner/tests.py b/tests/test_runner/tests.py
index b363514b2c..e3f4a8f4b6 100644
--- a/tests/test_runner/tests.py
+++ b/tests/test_runner/tests.py
@@ -352,9 +352,9 @@ class DeprecationDisplayTest(AdminScriptTestCase):
args = ['test', '--settings=test_project.settings', 'test_runner_deprecation_app']
out, err = self.run_django_admin(args)
self.assertIn("Ran 1 test", force_text(err))
- # change "Deprecation" to "RemovedInDjango\d+" in Django 1.11.
- six.assertRegex(self, err, r"DeprecationWarning: warning from test")
- six.assertRegex(self, err, r"DeprecationWarning: module-level warning from deprecation_app")
+ # change "NextVersion" to "RemovedInDjango\d+" in Django 1.11.
+ six.assertRegex(self, err, r"RemovedInNextVersionWarning: warning from test")
+ six.assertRegex(self, err, r"RemovedInNextVersionWarning: module-level warning from deprecation_app")
def test_runner_deprecation_verbosity_zero(self):
args = ['test', '--settings=test_project.settings', '--verbosity=0', 'test_runner_deprecation_app']